# Security Policy

## Supported Versions

Which versions of your project are
currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |

<!-- policy update schedule -->

## Disclosure

All known security vulnerabilities must be disclosed publically within 30 days of a detection during regular monitoring.

## Reporting a Vulnerability

This can be done directly through GitHub or via help@oziproject.dev
